Attribute VB_Name = "N6700MPS"
'Set of functions for the Agilent N67xx Modular Power Systems

Option Explicit

Public Function get_module_models(numbchan As Integer, instrument As VisaComLib.FormattedIO488)
'Get the model numbers of all the modules in a mainframe

    Dim mods() As String
    Dim i As Integer
    Dim command As String
    
    command = "SYST:CHAN?"
    numbchan = sendQry(command, instrument)
    
    ReDim mods(1 To CInt(numbchan))
    
    For i = 1 To numbchan
        command = "SYST:CHAN:MOD? (@" & CStr(i) & ")"
        mods(i) = sendQry(command, instrument)
    Next i
    
    get_module_models = mods
End Function

Public Sub get_module_features(numbchan As Integer, mods() As String, withRanges() As Integer, maxVs() As Double, maxIs() As Double, maxPs() As Double, mainstrument As VisaComLib.FormattedIO488)
'Get information for all of the modules in a mainframe

    Dim i As Integer
    
    ReDim withRanges(1 To numbchan)
    ReDim maxVs(1 To numbchan)
    ReDim maxIs(1 To numbchan)
    ReDim maxPs(1 To numbchan)
    
    For i = 1 To numbchan
    withRanges(i) = 0
        Select Case mods(i)
            Case "N6731B"
                maxVs(i) = 5
                maxIs(i) = 10
                maxPs(i) = 50
            Case "N6732B"
                maxVs(i) = 8
                maxIs(i) = 6.25
                maxPs(i) = 50
            Case "N6733B"
                maxVs(i) = 20
                maxIs(i) = 2.5
                maxPs(i) = 50
            Case "N6734B"
                maxVs(i) = 35
                maxIs(i) = 1.5
                maxPs(i) = 50
            Case "N6735B"
                maxVs(i) = 60
                maxIs(i) = 0.8
                maxPs(i) = 50
            Case "N6736B"
                maxVs(i) = 100
                maxIs(i) = 0.5
                maxPs(i) = 50
            Case "N6741B"
                maxVs(i) = 5
                maxIs(i) = 20
                maxPs(i) = 100
            Case "N6742B"
                maxVs(i) = 8
                maxIs(i) = 12.5
                maxPs(i) = 100
            Case "N6743B"
                maxVs(i) = 20
                maxIs(i) = 5
                maxPs(i) = 100
            Case "N6744B"
                maxVs(i) = 35
                maxIs(i) = 3
                maxPs(i) = 100
            Case "N6745B"
                maxVs(i) = 60
                maxIs(i) = 1.6
                maxPs(i) = 100
            Case "N6746B"
                maxVs(i) = 100
                maxIs(i) = 1
                maxPs(i) = 100
            Case "N6751A"
                maxVs(i) = 50
                maxIs(i) = 5
                maxPs(i) = 50
            Case "N6752A"
                maxVs(i) = 50
                maxIs(i) = 10
                maxPs(i) = 100
            Case "N6753A"
                maxVs(i) = 20
                maxIs(i) = 50
                maxPs(i) = 300
            Case "N6754A"
                maxVs(i) = 60
                maxIs(i) = 20
                maxPs(i) = 300
            Case "N6761A"
                withRanges(i) = 1
                maxVs(i) = 50
                maxIs(i) = 1.5
                maxPs(i) = 50
            Case "N6762A"
                withRanges(i) = 1
                maxVs(i) = 50
                maxIs(i) = 3
                maxPs(i) = 100
            Case "N6773A"
                maxVs(i) = 20
                maxIs(i) = 15
                maxPs(i) = 300
            Case "N6774A"
                maxVs(i) = 35
                maxIs(i) = 8.5
                maxPs(i) = 100
            Case "N6775A"
                maxVs(i) = 60
                maxIs(i) = 5
                maxPs(i) = 300
            Case "N6776A"
                maxVs(i) = 100
                maxIs(i) = 3
                maxPs(i) = 300
            Case Else
                MsgBox "This is not a recognized model number.  Please check your module and try again"
                maxVs(i) = 999
        End Select
    Next i
        
End Sub

Public Sub set_N6700_Voltage(channel As String, volts As String, instrument As VisaComLib.FormattedIO488)
'Set output voltage
    Dim command As String
    
    command = "VOLT " & volts & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_VprogR(channel As String, range As String, instrument As VisaComLib.FormattedIO488)
'Set output programming range
    Dim command As String
    
    command = "VOLT:RANG " & range & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_Current(channel As String, amps As String, instrument As VisaComLib.FormattedIO488)
'Set output current
    Dim command As String
    
    command = "CURR " & amps & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_IprogR(channel As String, range As String, instrument As VisaComLib.FormattedIO488)
'Set output programming range
    Dim command As String
    
    command = "CURR:RANG " & range & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_ov(channel As String, val As String, instrument As VisaComLib.FormattedIO488)
'Set over voltage protection
    Dim command As String
    
    command = "VOLT:PROT " & val & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_OCP(channel As String, state As String, instrument As VisaComLib.FormattedIO488)
'Set the state of the over current protection
    Dim command As String
    
    command = "CURR:PROT:STAT " & state & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_output_st(channel As String, state As String, instrument As VisaComLib.FormattedIO488)
'Turn the output on or off
    Dim command As String
    
    command = "OUTP " & state & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Sub set_N6700_VmeasR(channel As String, range As String, instrument As VisaComLib.FormattedIO488)
'Set voltage measurement range
    Dim command As String
    
    command = "SENS:VOLT:RANG " & range & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub

Public Function N6700meas_voltage(channel As String, instrument As VisaComLib.FormattedIO488)
'Measure output voltage
    Dim command As String
    
    command = "MEAS:VOLT? (@" & channel & ")"
    N6700meas_voltage = CDbl(sendQry(command, instrument))
End Function

Public Sub set_N6700_ImeasR(channel As String, range As String, instrument As VisaComLib.FormattedIO488)
'Set current measurement range
    Dim command As String
    
    command = "SENS:CURR:RANG " & range & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub
Public Function N6700meas_current(channel As String, instrument As VisaComLib.FormattedIO488)
'Measure output current
    Dim command As String
    
    command = "MEAS:CURR? (@" & channel & ")"
    N6700meas_current = CDbl(sendQry(command, instrument))
End Function

Public Function check_pwr_lim(channel As String, instrument As VisaComLib.FormattedIO488)
'Check the output power limit
    Dim command As String
    
    command = "POW:LIM? (@" & channel & ")"
    check_pwr_lim = CDbl(sendQry(command, instrument))
End Function

Public Sub change_pwr_lim(channel As String, limit As String, instrument As VisaComLib.FormattedIO488)
'Change the output power limit
    Dim command As String
    
    command = "POW:LIM " & limit & ",(@" & channel & ")"
    sendCmd command, instrument
End Sub
